pub struct SwfData {
pub account_id: String,
pub region: String,
pub domains: BTreeMap<String, Domain>,
pub activity_types: BTreeMap<String, TypeRecord>,
pub workflow_types: BTreeMap<String, TypeRecord>,
pub executions: BTreeMap<String, Execution>,
pub decision_tokens: BTreeMap<String, String>,
pub activity_tokens: BTreeMap<String, ActivityRef>,
pub tags: BTreeMap<String, BTreeMap<String, String>>,
}Expand description
Per-account Amazon SWF state.
Fields
account_id: Stringregion: Stringdomains: BTreeMap<String, Domain>Domains keyed by name.
activity_types: BTreeMap<String, TypeRecord>Activity types keyed by "{domain}\u{1}{name}\u{1}{version}".
workflow_types: BTreeMap<String, TypeRecord>Workflow types keyed by "{domain}\u{1}{name}\u{1}{version}".
executions: BTreeMap<String, Execution>Workflow executions keyed by runId.
decision_tokens: BTreeMap<String, String>Decision task token -> owning runId.
activity_tokens: BTreeMap<String, ActivityRef>Activity task token -> (runId, activityId).
Resource tags keyed by domain ARN.
Implementations
Sourceimpl SwfData
impl SwfData
Sourcepub fn type_map_key(domain: &str, name: &str, version: &str) -> String
pub fn type_map_key(domain: &str, name: &str, version: &str) -> String
Composite key for a type record within a domain.
Sourcepub fn find_execution<'a>(
&'a self,
workflow_id: &str,
run_id: Option<&str>,
) -> Option<&'a Execution>
pub fn find_execution<'a>( &'a self, workflow_id: &str, run_id: Option<&str>, ) -> Option<&'a Execution>
Find the currently-open execution for a workflow_id (SWF allows only
one open execution per workflow id at a time), preferring an exact
run_id when supplied.
pub fn find_execution_mut<'a>( &'a mut self, workflow_id: &str, run_id: Option<&str>, ) -> Option<&'a mut Execution>